# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [1.0.0] - 2020-10-12

- first official release


## [0.1.0-alpha.3] - 2020-10-11

### Fixed

- including the right directory in MANIFEST

### Added

- Warning when ESI status couldn't be loaded, for what ever reason


## [0.1.0-alpha.2] - 2020-10-11

### Changed

- Link to image in README updated since GitHub changed the default **master** branch to _main_. Fucking stupid change ...


## [0.1.0-alpha.1] - 2020-10-11

### Added

- initial version for testing purposes
